CompletionUninstallationException class

Describes an exception during the uninstallation of completion scripts.

Implemented types

Constructors

CompletionUninstallationException({required String message, required String rootCommand})
Describes an exception during the uninstallation of completion scripts.

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String
The error message for this exception
final
rootCommand → String
The command for which the installation failed.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited