ShellCompletionConfiguration class

Describes all the configuration needed to install completion scripts on a specific shell.

See:

Annotations
  • @immutable

Constructors

ShellCompletionConfiguration.fromSystemShell(SystemShell systemShell)
Creates a ShellCompletionConfiguration given the current SystemShell.
factory

Properties

completionConfigForShellFileName → String
The name for the config file for this shell.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scriptTemplate → CompletionScriptTemplate
Generates the contents of a completion script.
final
shell → SystemShell
A type definition for a shell.
final
shellRCFiles → List<String>
A preferential ordered list of locations of a config file that is run upon shell start. The list is to allow multiple options eg both .bash_profile and .bashrc. The first option will be tried first and and if the file doesn't exist the next one will be tried. Eg: .bash_profile or .zshrc
final
sourceLineTemplate → CompletionScriptTemplate
Generates a line to sources of a script file.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited