shellRCFiles property

List<String> shellRCFiles
final

A preferential ordered list of locations of a config file that is run upon shell start. The list is to allow multiple options eg both .bash_profile and .bashrc. The first option will be tried first and and if the file doesn't exist the next one will be tried. Eg: .bash_profile or .zshrc

Implementation

final List<String> shellRCFiles;