CompletionParser class

The workhorse of the completion system.

Responsible for discovering the possible completions given a CompletionLevel

Constructors

CompletionParser({required CompletionLevel completionLevel})
The workhorse of the completion system.

Properties

completionLevel → CompletionLevel
The CompletionLevel to parse.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse() → List<CompletionResult>
Parse the given CompletionState into a CompletionResult given the structure of commands and options declared by the CLIs ArgParser.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited