CompletionState class

A description of the state of a user input when requesting completion.

Created when parsing a completion request (when the user hits tab), it contains the information regarding the state of the user input in that moment.

Annotations
  • @immutable

Constructors

CompletionState({required int cword, required int point, required String line, required Iterable<String> args})
A description of the state of a user input when requesting completion.
const

Properties

args → Iterable<String>
The arguments that were passed by the user so far
final
cword → int
The index of the word being completed
final
hashCode → int
The hash code for this object.
no setterinherited
line → String
The user prompt that is being completed
final
point → int
The position of the cursor upon completion request
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromEnvironment([Map<String, String>? environmentOverride]) → CompletionState?
Creates a CompletionState from the environment variables set by the shell script.