MatchingCommandsCompletionResult class

A CompletionResult that suggests the sub commands in a completionLevel that matches pattern (A.K.A: startsWith).

If a command doesnt match the pattern, its aliases are also checked.

Inheritance

Constructors

MatchingCommandsCompletionResult({required CompletionLevel completionLevel, required String pattern})
A CompletionResult that suggests the sub commands in a completionLevel that matches pattern (A.K.A: startsWith).
const

Properties

completionLevel → CompletionLevel
The CompletionLevel in which the suggested commands are supposed to be located at.
final
completions → Map<String, String?>
A collection of MapEntry with completion suggestions to their descriptions.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
pattern → String
The pattern in which the matching commands will be suggested.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited