MatchingOptionsCompletionResult class

A CompletionResult that suggests the options in a completionLevel that starts with pattern.

If an option does not match the pattern, its aliases will be checked.

Inheritance

Constructors

MatchingOptionsCompletionResult({required CompletionLevel completionLevel, required String pattern})
A CompletionResult that suggests the options in a completionLevel that starts with pattern.
const

Properties

completionLevel → CompletionLevel
The CompletionLevel in which the suggested options are supposed to be located at.
final
completions → Map<String, String?>
A collection of MapEntry with completion suggestions to their descriptions.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
pattern → String
The pattern in which the matching options will be suggested.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited